@@ -10,11 +10,11 @@ pytest_plugins = "pytester"
 
 # could not make some of the tests work on PyPy, patches are welcome!
 skip_pypy = pytest.mark.skipif(
-    platform.python_implementation() == "PyPy", reason="could not make work on pypy"
+    platform.python_implementation() == "PyPy", reason="could not make it work on pypy"
 )
 
-# Python 3.8 changed the output formatting (bpo-35500).
-PY38 = sys.version_info >= (3, 8)
+# Python 3.8 changed the output formatting (bpo-35500), which has been ported to mock 3.0
+NEW_FORMATTING = sys.version_info >= (3, 8) or sys.version_info[0] == 2
 
 
 @pytest.fixture
@@ -209,7 +209,7 @@ class TestMockerStub:
 
     def __test_failure_message(self, mocker, **kwargs):
         expected_name = kwargs.get("name") or "mock"
-        if PY38:
+        if NEW_FORMATTING:
             msg = "expected call not found.\nExpected: {0}()\nActual: not called."
         else:
             msg = "Expected call: {0}()\nNot called"
@@ -238,7 +238,9 @@ def test_instance_method_spy(mocker):
     assert foo.bar(arg=10) == 20
     assert other.bar(arg=10) == 20
     foo.bar.assert_called_once_with(arg=10)
+    assert foo.bar.return_value == 20
     spy.assert_called_once_with(arg=10)
+    assert spy.return_value == 20
 
 
 @skip_pypy
@@ -272,6 +274,7 @@ def test_instance_method_by_subclass_spy(mocker):
     assert other.bar(arg=10) == 20
     calls = [mocker.call(foo, arg=10), mocker.call(other, arg=10)]
     assert spy.call_args_list == calls
+    assert spy.return_value == 20
 
 
 @skip_pypy
@@ -284,7 +287,9 @@ def test_class_method_spy(mocker):
     spy = mocker.spy(Foo, "bar")
     assert Foo.bar(arg=10) == 20
     Foo.bar.assert_called_once_with(arg=10)
+    assert Foo.bar.return_value == 20
     spy.assert_called_once_with(arg=10)
+    assert spy.return_value == 20
 
 
 @skip_pypy
@@ -301,7 +306,9 @@ def test_class_method_subclass_spy(mocker):
     spy = mocker.spy(Foo, "bar")
     assert Foo.bar(arg=10) == 20
     Foo.bar.assert_called_once_with(arg=10)
+    assert Foo.bar.return_value == 20
     spy.assert_called_once_with(arg=10)
+    assert spy.return_value == 20
 
 
 @skip_pypy
@@ -320,7 +327,9 @@ def test_class_method_with_metaclass_spy(mocker):
     spy = mocker.spy(Foo, "bar")
     assert Foo.bar(arg=10) == 20
     Foo.bar.assert_called_once_with(arg=10)
+    assert Foo.bar.return_value == 20
     spy.assert_called_once_with(arg=10)
+    assert spy.return_value == 20
 
 
 @skip_pypy
@@ -333,7 +342,9 @@ def test_static_method_spy(mocker):
     spy = mocker.spy(Foo, "bar")
     assert Foo.bar(arg=10) == 20
     Foo.bar.assert_called_once_with(arg=10)
+    assert Foo.bar.return_value == 20
     spy.assert_called_once_with(arg=10)
+    assert spy.return_value == 20
 
 
 @skip_pypy
@@ -350,7 +361,9 @@ def test_static_method_subclass_spy(mocker):
     spy = mocker.spy(Foo, "bar")
     assert Foo.bar(arg=10) == 20
     Foo.bar.assert_called_once_with(arg=10)
+    assert Foo.bar.return_value == 20
     spy.assert_called_once_with(arg=10)
+    assert spy.return_value == 20
 
 
 @contextmanager
@@ -561,6 +574,22 @@ def test_monkeypatch_native(testdir):
     )  # make sure there are no duplicated tracebacks (#44)
 
 
+def test_monkeypatch_no_terminal(testdir):
+    """Don't crash without 'terminal' plugin.
+    """
+    testdir.makepyfile(
+        """
+        def test_foo(mocker):
+            stub = mocker.stub()
+            stub(1, greet='hello')
+            stub.assert_called_once_with(1, greet='hey')
+        """
+    )
+    result = runpytest_subprocess(testdir, "-p", "no:terminal", "-s")
+    assert result.ret == 1
+    assert result.stdout.lines == []
+
+
 @pytest.mark.skipif(sys.version_info[0] < 3, reason="Py3 only")
 def test_standalone_mock(testdir):
     """Check that the "mock_use_standalone" is being used.
@@ -604,7 +633,7 @@ def test_detailed_introspection(testdir):
     """
     )
     result = testdir.runpytest("-s")
-    if PY38:
+    if NEW_FORMATTING:
         expected_lines = [
             "*AssertionError: expected call not found.",
             "*Expected: mock('', bar=4)",
@@ -623,7 +652,7 @@ def test_detailed_introspection(testdir):
         "*Use -v to get the full diff*",
         "*Kwargs:*",
         "*assert {} == {'bar': 4}*",
-        "*Right contains more items:*",
+        "*Right contains* more item*",
         "*{'bar': 4}*",
         "*Use -v to get the full diff*",
     ]
